==> ssb_dash_components-0.5.0.tar.gz: ssb_dash_components-0.5.0/README.md <==
# SSB Dash Components

_The [SSB Component Library](https://design.ssb.no/), available for Dash!_

## Components

| Component              | Available for Dash? |
| ---------------------- | ------------------- |
| Accordion              | :white_check_mark:  |
| Breadcrumb             |                     |
| Button                 | :white_check_mark:  |
| Cards                  |                     |
| Checkbox               |                     |
| Divider                |                     |
| Dropdown               | :white_check_mark:  |
| Fact Box               |                     |
| Footer                 |                     |
| Form Error             |                     |
| Glossary               |                     |
| Graphs                 |                     |
| Header                 | :white_check_mark:  |
| Input                  | :white_check_mark:  |
| Key Figures            |                     |
| Links                  |                     |
| Map                    |                     |
| Pagination             |                     |
| Quote and Highlighting |                     |
| Radio Buttons          |                     |
| Responsive media       |                     |
| Reference              |                     |
| Search                 |                     |
| Site navigation        |                     |
| Sticky menu            |                     |
| Table                  |                     |
| Tabs                   | :white_check_mark:  |
| Tags                   |                     |
| Warnings and errors    |                     |

==> ssb_dash_components-0.5.3.tar.gz: ssb_dash_components-0.5.3/README.md <==
# SSB Dash Components

_The [SSB Component Library](https://design.ssb.no/), available for Dash!_

## Components

| Component              | Available for Dash? |
| ---------------------- | ------------------- |
| Accordion              | :white_check_mark:  |
| Breadcrumb             |                     |
| Button                 | :white_check_mark:  |
| Cards                  |                     |
| Checkbox               |                     |
| Divider                |                     |
| Dropdown               | :white_check_mark:  |
| Fact Box               |                     |
| Footer                 |                     |
| Form Error             |                     |
| Glossary               | :white_check_mark:  |
| Graphs                 |                     |
| Header                 | :white_check_mark:  |
| Input                  | :white_check_mark:  |
| Key Figures            |                     |
| Links                  |                     |
| Map                    |                     |
| Pagination             |                     |
| Quote and Highlighting |                     |
| Radio Buttons          |                     |
| Responsive media       |                     |
| Reference              |                     |
| Search                 |                     |
| Site navigation        |                     |
| Sticky menu            |                     |
| Table                  |                     |
| Tabs                   | :white_check_mark:  |
| Tags                   |                     |
| Warnings and errors    |                     |
